@@ -22,7 +22,7 @@
 #define HAVE_ALLOCA_H 1
 #define HAVE_AIO_H 1
 #define HAVE_ARPA_INET_H 1
-/* #undef HAVE_ASM_MSR_H */
+#define HAVE_ASM_MSR_H 1
 #define HAVE_ASM_TERMBITS_H 1
 #define HAVE_BSEARCH 1
 #define HAVE_CRYPT_H 1
@@ -109,7 +109,7 @@
 #define HAVE_SYS_PARAM_H 1
 
 /* Libraries */
-/* #undef HAVE_LIBPTHREAD */
+#define HAVE_LIBPTHREAD 1
 #define HAVE_LIBM 1
 #define HAVE_LIBDL 1
 #define HAVE_LIBRT 1
@@ -324,7 +324,7 @@
 #define USE_MB_IDENT 1
 
 /* this means that valgrind headers and macros are available */
-/* #undef HAVE_VALGRIND */
+#define HAVE_VALGRIND 1
 
 /* this means WITH_VALGRIND - we change some code paths for valgrind */
 /* #undef HAVE_valgrind */
@@ -520,6 +520,11 @@
 #endif
 #define PSAPI_VERSION 1     /* for GetProcessMemoryInfo() */
 
+/* We don't want the min/max macros */
+#ifdef __WIN__
+#define NOMINMAX
+#endif
+
 /*
   MySQL features
 */
@@ -624,16 +629,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 0
-#define MYSQL_VERSION_PATCH 10
+#define MYSQL_VERSION_PATCH 17
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.0.10"
+#define PACKAGE_STRING "MySQL Server 10.0.17"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.0.10"
-#define VERSION "10.0.10"
+#define PACKAGE_VERSION "10.0.17"
+#define VERSION "10.0.17"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "bundled jemalloc"
@@ -643,4 +648,29 @@
 #define SIZEOF_TIME_T 8
 /* #undef TIME_T_UNSIGNED */
 
+#ifdef _AIX
+/*
+  AIX includes inttypes.h from sys/types.h
+  Explicitly request format macros before the first inclusion of inttypes.h
+*/
+#define __STDC_FORMAT_MACROS
+#endif
+
+/*
+  stat structure (from <sys/stat.h>) is conditionally defined
+  to have different layout and size depending on the defined macros.
+  The correct macro is defined in my_config.h, which means it MUST be
+  included first (or at least before <features.h> - so, practically,
+  before including any system headers).
+
+  Check the include order by looking at __GLIBC__ (defined in <features.h>)
+
+  But we cannot force all third-party clients/connectors to include
+  my_config.h first. So, their crashes are their responsibility,
+  we enable this check only for MariaDB sources (SAFE_MUTEX check).
+*/
+#if defined(__GLIBC__) && defined(SAFE_MUTEX)
+#error <my_config.h> MUST be included first!
+#endif
+
 #endif
